# VizDaTo
> Visualize Data Today aims to make it fast and easy to run initial exploratory visualizations on any given dataset. These visuals will follow industry best practices based on column types


This file will become your README and also the index of your documentation.

## Install

`pip install vizdato`

## How to use

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


